<img align="left" height="120" src="docs/assets/logo.png">

# KraK - Build Tools for Computational Analyses

[![Build Status](https://travis-ci.com/yetisir/krak.svg?branch=master)](https://travis-ci.co/yetisir/krak) [![Coverage Status](https://coveralls.io/repos/github/yetisir/krake/badge.svg?branch=master)](https://coveralls.io/github/yetisir/krak?branch=master) [![Maintainability](https://api.codeclimate.com/v1/badges/78f17dc4e5d8ebfad02e/maintainability)](https://codeclimate.com/github/yetisir/krak/maintainability) [![Documentation Status](https://readthedocs.org/projects/krak/badge/?version=latest)](https://krak.readthedocs.io/en/latest/?badge=latest)
  

KraK is a Python library to help build and run computational geomechnical models. 

## Installation

The latest stable release of KraK can be installed with [pip](https://pip.pypa.io/en/stable/).
 
```bash
python -m pip install krak
```

## Documentation

The latest documentation is hosted [here](https://krak.readthedocs.io/en/latest/?badge=latest)


## License
dNote is licensed under the  [GNU GPLv3](https://choosealicense.com/licenses/gpl-3.0/)

